# Copyright (c) 2019 Analog Devices, Inc.  All rights reserved.

# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#   - Redistributions of source code must retain the above copyright notice, this 
#     list of conditions and the following disclaimer.
#   - Redistributions in binary form must reproduce the above copyright notice, 
#     this list of conditions and the following disclaimer in the documentation 
#     and/or other materials provided with the distribution.  
#   - Modified versions of the software must be conspicuously marked as such.
#   - This software is licensed solely and exclusively for use with 
#     processors/products manufactured by or for Analog Devices, Inc.
#   - This software may not be combined or merged with other code in any manner 
#     that would cause the software to become subject to terms and conditions 
#     which differ from those listed here.
#   - Neither the name of Analog Devices, Inc. nor the names of its contributors 
#     may be used to endorse or promote products derived from this software 
#     without specific prior written permission.
#   - The use of this software may or may not infringe the patent rights of one 
#     or more patent holders.  This license does not release you from the 
#     requirement that you obtain separate licenses from these patent holders 
#     to use this software.

# THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS" AND 
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
# NON-INFRINGEMENT, TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
# ARE DISCLAIMED. 
# 
# IN NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR CONSEQUENTIAL DAMAGES 
# (INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF CLAIMS OF INTELLECTUAL 
# PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import csv
import numpy as np
import pandas as pd
from datetime import datetime

def export_data(codes, volts, inl, dnl):
    """Exports data onto an excel file.

    Parameters
    ----------
    codes : list[int]
        The list of integer codes applied.
    volts : list[float]
        The list of voltages read back from the instrument.
    inl : list[float]
        The list of INL values represented in LSBs.
    dnl : list[float]
        The list of DNL values represented ih LSBs.
    """

    codes_dict = {'Codes' : codes}
    volts_dict = {'Voltage' : volts}
    inl_dict = {'INL' : inl}
    dnl_dict = {'DNL' : [0] + dnl}

    df_codes = pd.DataFrame(codes_dict)
    df_volts = pd.DataFrame(volts_dict)
    df_inl = pd.DataFrame(inl_dict)
    df_dnl = pd.DataFrame(dnl_dict)

    df_final = pd.concat([df_codes, df_volts, df_inl, df_dnl], axis = 1)
    filename = datetime.now().strftime('AD5791_Code_Result-%Y-%m-%d-%H-%M.csv')
    export_csv = df_final.to_csv(filename, index = None, header=True)
    return
