# Copyright (c) 2019 Analog Devices, Inc.  All rights reserved.

# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#   - Redistributions of source code must retain the above copyright notice, this 
#     list of conditions and the following disclaimer.
#   - Redistributions in binary form must reproduce the above copyright notice, 
#     this list of conditions and the following disclaimer in the documentation 
#     and/or other materials provided with the distribution.  
#   - Modified versions of the software must be conspicuously marked as such.
#   - This software is licensed solely and exclusively for use with 
#     processors/products manufactured by or for Analog Devices, Inc.
#   - This software may not be combined or merged with other code in any manner 
#     that would cause the software to become subject to terms and conditions 
#     which differ from those listed here.
#   - Neither the name of Analog Devices, Inc. nor the names of its contributors 
#     may be used to endorse or promote products derived from this software 
#     without specific prior written permission.
#   - The use of this software may or may not infringe the patent rights of one 
#     or more patent holders.  This license does not release you from the 
#     requirement that you obtain separate licenses from these patent holders 
#     to use this software.

# THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS" AND 
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
# NON-INFRINGEMENT, TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
# ARE DISCLAIMED. 
# 
# IN NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR CONSEQUENTIAL DAMAGES 
# (INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF CLAIMS OF INTELLECTUAL 
# PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import ACERemoteController as arc
import VISAController as vsc
import DACFunctions as dacfunc
import MatPlotGraph as pltdac
import time
import DNL_INL as dnl_inl
import numpy
import CSVExporter

codes = []
volts = []
volt_apply = []

# Constants
board = 'EVAL-AD5791SDZ'
chip = 'AD5791'
# Set your ACE installation path
ace_path = r'C:\Program Files (x86)\Analog Devices\ACE'
# Change GPIB address to the appropriate one for your system.
gpib_instr_address = 'GPIB0::24::INSTR'
# Refer your instrument manual for the correct command for your instrument.
read_command = 'TARM SGL'

client = arc.establish_connection(board, chip, ace_path)
arc.reset(client)

mincode = 0
maxcode = 0xFFFFF
codestep = 0x1000
vspan = 20

resolution = 16
if (chip == 'AD5791') or (chip == 'AD5790'):
    resolution = 20
else:
    if(chip == 'AD5781') or (chip == 'AD5780'):
        resolution = 18

dacfunc.remove_output_clamp(client)

for code in range(mincode, maxcode, codestep):
    codes.append(code)
    dacfunc.write_dac_code(client, code, resolution, True)
    # Give time delays if necessary.
    # time.sleep(1)
    v = vsc.get_value(gpib_instr_address)
    print(v)
    volts.append(v)

inl = dnl_inl.compute_inl(volts, codestep)
dnl = dnl_inl.compute_dnl(volts, codestep, resolution, vspan)
pltdac.plot_dac_codes(codes, volts)
pltdac.plot_inl(codes, inl)
pltdac.plot_dnl(codes[1:], dnl)
pltdac.complete_plot()
CSVExporter.export_data(codes, volts, inl, dnl)